betty.openapi module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.openapi module

Provide the OpenAPI specification.

class betty.openapi.Specification

  Bases: `object`

  Build OpenAPI specifications.

  __init__(project: Project)
  async build() → MutableMapping[str, bool | int | float | str | None | MutableSequence[bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]] | MutableMapping[str, bool | int | float | str | None | MutableSequence[Dump] | MutableMapping[str, Dump]]]

    Build the OpenAPI specification.